===============================================
django-waitinglist: waiting list app for Django
===============================================

.. image:: https://img.shields.io/travis/pinax/django-waitinglist.svg
    :target: https://travis-ci.org/pinax/django-waitinglist

.. image:: https://img.shields.io/coveralls/pinax/django-waitinglist.svg
    :target: https://coveralls.io/r/pinax/django-waitinglist

.. image:: https://img.shields.io/pypi/dm/django-waitinglist.svg
    :target:  https://pypi.python.org/pypi/django-waitinglist/

.. image:: https://img.shields.io/pypi/v/django-waitinglist.svg
    :target:  https://pypi.python.org/pypi/django-waitinglist/

.. image:: https://img.shields.io/badge/license-MIT-blue.svg
    :target:  https://pypi.python.org/pypi/django-waitinglist/



Provides a waiting list for running a private beta with cohorts support.

Requirements
============

* Django 1.4
* django-appconf (included in ``install_requires``)
* django-user-accounts_ (not included in ``install_requires``)

.. _django-user-accounts: https://github.com/pinax/django-user-accounts

Documentation
=============

See http://django-waitinglist.readthedocs.org/
